Data containing Zika cases as reported by the United States Virgin Islands department of Health and scraped into CDC's public Zika data github repository.
data(my.data)A data frame of 32 observations and 9 variables.
Date when report was published by USVI Department of Health, YYYY-mm-dd
Regional location by name
The type of location
The type of case presented
A code to identify the data_field
The time period of the cases
The units of the time period
The number of observations under a specificc data_field
The unit of the number of observations, cases, municipalities...
Dania M. Rodriguez, Michael A Johansson, Luis Mier-y-Teran-Romero, moiradillon2, eyq9, YoJimboDurant, <U+2026> Daniel Mietchen. (2017). cdcepi/zika: March 31, 2017 [Data set]. Zenodo. (zenodo)